__author__ = 'Joe Linn'

from .abstract import AbstractQuery


class Text(AbstractQuery):
    def set_field(self, field, values):
        """
        Set the field for this query
        @param field:
        @type field: str
        @param values:
        @type values: mixed
        @return:
        @rtype: self
        """
        return self.set_param(field, values)

    def set_field_param(self, field, key, value):
        """
        Set a param for the given field
        @param field:
        @type field: str
        @param key:
        @type key: str
        @param value:
        @type value: str or int
        @return:
        @rtype: self
        """
        if field not in self._params:
            self._params[field] = {}
        self._params[field][key] = value
        return self

    def set_field_query(self, field, query):
        """
        Set the query string for the given field
        @param field:
        @type field: str
        @param query:
        @type query: str
        @return:
        @rtype: self
        """
        return self.set_field_param(field, 'query', query)

    def set_field_type(self, field, query_type):
        """
        Set the query type for the field
        @param field:
        @type field: str
        @param query_type: text query type
        @type query_type: str
        @return:
        @rtype: self
        """
        return self.set_field_param(field, 'type', query_type)

    def set_field_max_expansions(self, field, max_expansions):
        """
        Set field max expansions
        @param field:
        @type field: str
        @param max_expansions:
        @type max_expansions: int
        @return:
        @rtype: self
        """
        return self.set_field_param(field, 'max_expansions', max_expansions)



__author__ = 'Joe Linn'

from .abstract import AbstractQuery


class Field(AbstractQuery):
    def __init__(self, field='', query_string=''):
        """

        @param field: optional field name
        @type field: str
        @param query_string: optional query string
        @type query_string: str
        """
        super(Field, self).__init__()
        self.set_field(field).set_query_string(query_string)

    def set_field(self, field):
        """
        Set the field
        @param field:
        @type field: str
        @return:
        @rtype: self
        """
        self._field = str(field)
        return self

    def set_query_string(self, query_string):
        """
        Set a new query string
        @param query_string:
        @type query_string: str
        @return:
        @rtype: self
        """
        assert isinstance(query_string, str), "query_string must be a str: %r" % query_string
        self._query_string = query_string
        return self

    def to_dict(self):
        """

        @return:
        @rtype: dict
        """
        self.set_param(self._field, {'query': self._query_string})
        return super(Field, self).to_dict()


